@@ -55,7 +55,7 @@ public :
     iterator Insert(const std::string& key, Node* node) PLIST_WARN_DEPRECATED("use Set() instead");
     void Remove(Node* node);
     void Remove(const std::string& key);
-    std::string GetNodeKey(Node* key);
+    std::string GetNodeKey(Node* node);
 
 private :
     std::map<std::string,Node*> _map;
